==> image-editor_1.0.11.orig.tar.xz: image-editor-1.0.11/libimageviewer/translations/libimageviewer_ko.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ko" version="2.1">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>이미지 정보</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>기본 정보</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>상세 정보</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>앨범에 추가</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>새 앨범</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>모든 이미지</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>이미지 열기</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>엘범에서 제거</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>즐겨찾기 해제</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>즐겨찾기</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>이미지를 볼 수 있는 권한이 없습니다</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>형식</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>수정된 날짜</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>파일 크기</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>캡처된 날짜</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>노출 모드</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>노출 프로그램</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>노출 시간</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>플래시</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>조리개</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>초점 거리</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>최대 조리개</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>미터링 모드</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>화이트 밸런스</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>플래시 보정</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>렌즈 모델</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>색상공간</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>카메라 모델</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>치수</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>태그</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>뒤로</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>이전</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>다음</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 크기</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>창에 맞춤</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>시계 반대 방향으로 회전</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>시계 방향으로 회전</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>전체화면 종료</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>전체화면</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>인쇄</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>슬라이드 표시</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>이름 변경</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>탐색 창 표시</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>탐색 창 숨기기</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>바탕화면으로 설정</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>파일 관리도구에 표시</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>이미지 정보</translation>
    </message>
    <message>
        <source>day</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>확인</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>새 이름 입력</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>이전</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>일시중지</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>재생</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>다음</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>종료</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>이미지 파일을 찾을 수 없음</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>이미지 파일을 찾을 수 없음</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> image-editor_1.0.24.orig.tar.xz: image-editor-1.0.24/libimageviewer/translations/libimageviewer_ko.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>이미지 정보</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>기본 정보</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>상세 정보</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>앨범에 추가</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>새 앨범</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>모든 이미지</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>이미지 열기</translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>엘범에서 제거</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>즐겨찾기 해제</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>즐겨찾기</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>이미지를 볼 수 있는 권한이 없습니다</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>이름</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>형식</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>수정된 날짜</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>파일 크기</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>캡처된 날짜</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>노출 모드</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>노출 프로그램</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>노출 시간</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>플래시</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>조리개</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>초점 거리</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>최대 조리개</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>미터링 모드</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>화이트 밸런스</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>플래시 보정</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>렌즈 모델</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>색상공간</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>카메라 모델</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>치수</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>태그</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>뒤로</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>이전</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>다음</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1 크기</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>창에 맞춤</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>시계 반대 방향으로 회전</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>시계 방향으로 회전</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>전체화면 종료</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>전체화면</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>인쇄</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>슬라이드 표시</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>이름 변경</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>탐색 창 표시</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>탐색 창 숨기기</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>바탕화면으로 설정</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>파일 관리도구에 표시</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>이미지 정보</translation>
    </message>
    <message>
        <source>day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>확인</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>새 이름 입력</translation>
    </message>
    <message>
        <source>The file already exists, please use another name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>이전</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>일시중지</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>재생</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>다음</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>종료</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>이미지 파일을 찾을 수 없음</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>이미지 파일을 찾을 수 없음</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
